@@ -13,7 +13,7 @@ The intent of this document is to state the conditions under which a
 Package may be copied, such that the Copyright Holder maintains some 
 semblance of artistic control over the development of the package, 
 while giving the users of the package the right to use and distribute 
-the Package in a more-or-less customary fashion, plus the right to 
+the Package in a more-or-less customary fashion, plus the right to
 make reasonable modifications. 
 
 Definitions
@@ -142,6 +142,7 @@ typedef map<size_t,string> SEQMAP;
 #include "mcleave.h"
 #include "mspectrumcondition.h"
 #include "mreport.h"
+#include "mzid_report.h"
 #include "msequenceserver.h"
 #include "mplugin.h"
 #include "msemistate.h"
@@ -302,6 +303,8 @@ public:
 	bool score_each_sequence(); // generates a score for all sequences in the m_svrSequences object
 	bool set_threads(const unsigned long _t); // sets the object's thread number
 	bool set_thread(const unsigned long _t); // sets the object's thread number
+	bool dynamic_parent_ion_selection(const double _d,const double _maxe); //selects a parent ion mass window for high resolution spectra dalton space
+	bool dynamic_parent_ion_selection_ppm(const double _d, const double _maxe); //selects a parent ion mass window for high resolution spectra in ppm space
 	int set_round(const int _r)	{ m_iCurrentRound = _r; return m_iCurrentRound;}
 	virtual bool load_sequences();
 	XmlParameter m_xmlPerformance; // stores process performance parameters
@@ -369,11 +372,14 @@ protected:
 	bool m_bQuickAcetyl;
 	bool m_bQuickPyro;
 	double m_dEsum;
-
+	bool m_bChargeDither;
+	float m_fSavResolve;
+	bool m_bSavResolve;
 	set<size_t> m_setRound;
 	vector<string> m_vstrSaps;
 	vector<string> m_vstrMods;
 	map<string,string> m_mapAnnotation;
+	map<string,string>* m_pmapAnnotation;
 	msemistate m_semiState; // maintains the state of the semi-enzymatic cleavage state machine
 	mpyrostate m_pyroState; // maintains the state of the pyrolidone carboxylic acid detection state machine
 	merrors m_errValues;
@@ -392,6 +398,7 @@ protected:
 	bool m_bUn; // if true, cleave at all residues. if false, use cleavage specification in data input.
 	bool m_bUseHomologManagement; // set to true to use homologue management 
 	size_t m_tMinResidues; // the minimum peptide length that will be scored
+	size_t m_tMaxResidues; // the maximum peptide length that will be scored
 	size_t m_tMissedCleaves; // the maximum number of cleavage sites that can be missed
 	size_t m_tPeptideCount; // the total number of peptide sequences generated during a process
 	size_t m_tPeptideScoredCount; // the total number of peptide sequences scored during a process
@@ -437,7 +444,7 @@ protected:
 	bool score(const msequence &_s); // generates scores of an msequence object
 	bool score_single(const msequence &_s); // generates scores of an msequence object
 	bool score_terminus(const string &_s); // attempts to find N or C terminal modified peptides
-	bool score_terminus_single(const string &_s); // attempts to find N or C terminal modified peptides
+//	bool score_terminus_single(const string &_s); // attempts to find N or C terminal modified peptides
 	bool spectra(void); // loads the m_vSpectra object using the m_specCondition object
 	bool spectra_force(string &_t,string &_v); // forces the spectrum loader to use a specified file type
 	bool subtract(void); // remove redundant mass spectra
