@@ -322,6 +322,7 @@ public:
 	virtual ~mscore(void);
 public:
 	double m_dErr; // error for the fragment ions
+	size_t m_tScored;
 	double m_dHomoError;
 	float m_fHyper; // current hyper score
 	double m_dParentErrMinus; // error for the parent ion M+H (not m/z)
@@ -409,6 +410,23 @@ public:
 	bool reset_permute();
 	bool permute();
 	bool set_phospho_bias(const bool _b);
+	__inline__ bool check_terminii(void) {
+		return !m_seqUtil.m_piCtMod[m_pSeq[m_lSeqLength - 1]];
+	};
+	__inline__ bool set_complexity(const double _d) {
+		if (_d < 1.0) {
+			m_dComplexity = 1.0;
+		}
+		if (_d > 10.0) {
+			m_dComplexity = 10.0;
+		}
+		else
+		{
+			m_dComplexity = _d;
+		}
+		m_lComplexity = (unsigned long)pow(2.0, m_dComplexity);
+		return true;
+	};
 
 public:
 	enum	{
@@ -445,15 +463,19 @@ protected:
 	bool m_bIsotopeError; // true if the spectrum mass may be associated with the wrong isotopic peak
 	unsigned long m_lMILength; // current length of the mi vector
 	unsigned long m_lSeqLength; // current sequence length
+	unsigned long m_lMaxSeqLength; // current sequence length
+	unsigned long m_lMinSeqLength; // current sequence length
 	unsigned long m_lSize; // maximum sequence length - this can be adjusted on the fly
+	unsigned long m_lComplexity;
 	long m_lSpectra; // current length of the m_vSpec vector
 	unsigned long m_lErrorType; // current ion mass accuracy information - value from mscore_error
 	float m_fScore; // current convolution score
 	double m_dSeqMH; // current sequence M+H - changed from m_fSeqMH to improve accuracy of parent ion mass calculations
 	double m_dWidth; // current half-width of the entry for a single fragment ion in the m_vsmapMI map
 	                // this value is used by blur
+	double m_dComplexity;
 	float *m_pfSeq; // residue masses corresponding to the current sequence in daltons
-	unsigned long *m_plAA;
+	int *m_piAA;
 	unsigned long *m_plSeq; // residue masses corresponding to the current sequence, converted into integers
 //	char *m_pSeq; // the current sequence
 	size_t m_lId; // id of the current spectrum
