@@ -172,8 +172,9 @@ public:
                                             //where all residues between m_lFirstS & this one are modified
       unsigned long m_lLastS; // cursor index to the most C-terminal residue modified in a peptide,
                                         // effectively the length of m_ppModsS
-      unsigned long m_lStates;
-      long m_lSizeS; // maximum peptide length
+      unsigned long m_lStates;	//number of states checked in the current session
+	  unsigned long m_lStatesT;	//number of states checked in the current session
+	  long m_lSizeS; // maximum peptide length
       long m_lSizeEqualsS; // maximum length of EqualS array
       size_t *m_plEqualsS; // indexes of spectra with M+H within error of the current modified peptide M+H
       unsigned long *m_piMods;
@@ -215,6 +216,7 @@ public:
             check_size(_s);
             strcpy(m_pSeqS,_p);
             m_lStates = 0;
+			m_lStatesT = 0;
             m_lFilledS = 0;
             m_lCursorS = 0;
             m_bStateS = true;
