@@ -183,7 +183,6 @@ mspectrumcondition::mspectrumcondition(void)
 	m_bUseParent = true;
 	m_bUseLowestMass = true;
 	m_bUseMinSize = true;
-	m_bUseNoiseSuppression = true;
 	m_bUseChargeSuppression = true;
 	m_bCondition = true;
 	m_bUseNeutralLoss = false;
@@ -267,23 +266,6 @@ bool mspectrumcondition::condition(mspectrum &_s, mscore &_score)
 	if(!_score.precondition(_s)) {
 		return false;
 	}
-/*
- * check the parent ion charge and return false if it is too large
- */
-	if(m_bUseNoiseSuppression)	{
-		/*
-		 * check the parent ion mass against the minimum mass allowed (about 600.0 is usually safe)
-		*/
-		if(m_bUseMinMass)	{
-			if(_s.m_dMH < m_fMinMass)
-				return false;
-		}
-		if(m_bUseChargeSuppression)	{
-			if((long)(_s.m_fZ+0.5) > m_lMaxCharge)	{
-				return false;
-			}
-		}
-	}
 	size_t tSize = _s.m_vMI.size();
 	size_t a = 0;
 	float fMaxI = 0;
@@ -336,14 +318,6 @@ bool mspectrumcondition::condition(mspectrum &_s, mscore &_score)
 		if((long)_s.m_vMI.size() < m_lMinSize)
 			return false;
 	}
-/*
- * check to see if the spectrum has the characteristics of noise 
- */
-	if(m_bUseNoiseSuppression)	{
-		if(is_noise(_s))	{
-			return false;
-		}
-	}
 /*
 * retrieve the N most intense peaks
 */
@@ -501,33 +475,6 @@ bool mspectrumcondition::clean_isotopes(mspectrum &_s)
         return true;
 
 }
-/*
- * is_noise attempts to determine if the spectrum is simply noise. if the spectrum
- * does not have any peaks within a window near the parent ion mass, it is considered
- * noise.
- */
-
-bool mspectrumcondition::is_noise(mspectrum &_s)
-{
-	if(!m_bUseNoiseSuppression)
-		return false;
-	size_t a = 0;
-	size_t tSize = _s.m_vMI.size();
-	float fZ = _s.m_fZ;
-	float fMax = (float)(_s.m_dMH/fZ);
-	if(fZ == 1)	{
-		fMax = (float)(_s.m_dMH - 600.0);
-	}
-	if(fZ == 2)	{
-		fMax = (float)(_s.m_dMH - 600.0);
-	}
-	while(a < tSize)	{
-		if(_s.m_vMI[a].m_fM > fMax)
-			return false;
-		a++;
-	}
-	return true;
-}
 /*
  * load makes internal copies of the relavent parameters found in the XmlParameter object
  */
@@ -573,19 +520,7 @@ bool mspectrumcondition::load(XmlParameter &_x)
 			m_bCondition = true;
 		}
 	}
-	strKey = "spectrum, use noise suppression";
-	bool bUseNoiseSuppression = _x.get(strKey,strValue);
-	if(bUseNoiseSuppression)	{
-		if(strValue == "yes")	{
-			m_bUseNoiseSuppression = true;
-		}
-		else if(strValue == "no")	{
-			m_bUseNoiseSuppression = false;
-		}
-		else	{
-			m_bUseNoiseSuppression = true;
-		}
-	}
+
 	strKey = "spectrum, use neutral loss window";
 	bool bUseNeutralLoss = _x.get(strKey,strValue);
 	if(bUseNeutralLoss)	{
@@ -773,13 +708,6 @@ bool mspectrumcondition::remove_neutral(mspectrum &_s)
 	}
 	return true;
 }
-/*
- * get_noise_suppression gets the current value of the m_bUseNoiseSuppression member
- */
-bool mspectrumcondition::get_noise_suppression(void)
-{
-	return m_bUseNoiseSuppression;
-}
 /*
  * set_max_peaks sets the current value of the m_tMaxPeaks member
  */
@@ -877,14 +805,6 @@ bool mspectrumcondition::use_dynamic_range(const bool _f)
 	m_bUseDynamicRange = _f;
 	return m_bUseDynamicRange;
 }
-/*
- * use_noise_suppression sets the current value of the m_bUseNoiseSuppression member
- */
-bool mspectrumcondition::use_noise_suppression(const bool _f)
-{
-	m_bUseNoiseSuppression = _f;
-	return m_bUseNoiseSuppression;
-}
 /*
  * use_lowest_mass sets the current value of the m_bUseLowestMass member
  */
